@@ -1,50 +1,69 @@
+# This file is part of the django-environ.
+#
+# Copyright (c) 2021, Serghei Iakovlev <egrep@protonmail.ch>
+# Copyright (c) 2013-2021, Daniele Faraglia <daniele.faraglia@gmail.com>
+#
+# For the full copyright and license information, please view
+# the LICENSE.txt file that was distributed with this source code.
+
 """
 Django-environ allows you to utilize 12factor inspired environment
 variables to configure your Django application.
 """
+
 import ast
 import logging
 import os
 import re
 import sys
+import urllib.parse as urlparselib
 import warnings
-from .compat import (
-    json, urlparselib, urlparse, urlunparse, ParseResult, parse_qs,
-    unquote_plus, DJANGO_POSTGRES, REDIS_DRIVER, ImproperlyConfigured, basestring)
+from urllib.parse import (
+    parse_qs,
+    ParseResult,
+    unquote_plus,
+    urlparse,
+    urlunparse,
+)
+
+from .compat import DJANGO_POSTGRES, ImproperlyConfigured, json, REDIS_DRIVER
+
+try:
+    from os import PathLike
+
+    Openable = (str, PathLike)
+except ImportError:
+    Openable = (str,)
 
 logger = logging.getLogger(__name__)
 
 
-VERSION = '0.4.5'
-__author__ = 'joke2k'
-__version__ = tuple(VERSION.split('.'))
-
-
 def _cast(value):
     # Safely evaluate an expression node or a string containing a Python
     # literal or container display.
     # https://docs.python.org/3/library/ast.html#ast.literal_eval
     try:
         return ast.literal_eval(value)
-    except ValueError:
+    except (ValueError, SyntaxError):
         return value
 
-# return int if possible
+
 def _cast_int(v):
+    """Return int if possible."""
     return int(v) if hasattr(v, 'isdigit') and v.isdigit() else v
 
+
 def _cast_urlstr(v):
     return unquote_plus(v) if isinstance(v, str) else v
 
 
-class NoValue(object):
+class NoValue:
 
     def __repr__(self):
-        return '<{0}>'.format(self.__class__.__name__)
+        return '<{}>'.format(self.__class__.__name__)
 
 
-class Env(object):
-
+class Env:
     """Provide scheme-based lookups of environment variables so that each
     caller doesn't have to pass in `cast` and `default` parameters.
 
@@ -59,6 +78,10 @@ class Env(object):
     NOTSET = NoValue()
     BOOLEAN_TRUE_STRINGS = ('true', 'on', 'ok', 'y', 'yes', '1')
     URL_CLASS = ParseResult
+
+    POSTGRES_FAMILY = ['postgres', 'postgresql', 'psql', 'pgsql', 'postgis']
+    ELASTICSEARCH_FAMILY = ['elasticsearch' + x for x in ['', '2', '5', '7']]
+
     DEFAULT_DATABASE_ENV = 'DATABASE_URL'
     DB_SCHEMES = {
         'postgres': DJANGO_POSTGRES,
@@ -78,7 +101,12 @@ class Env(object):
         'sqlite': 'django.db.backends.sqlite3',
         'ldap': 'ldapdb.backends.ldap',
     }
-    _DB_BASE_OPTIONS = ['CONN_MAX_AGE', 'ATOMIC_REQUESTS', 'AUTOCOMMIT']
+    _DB_BASE_OPTIONS = [
+        'CONN_MAX_AGE',
+        'ATOMIC_REQUESTS',
+        'AUTOCOMMIT',
+        'DISABLE_SERVER_SIDE_CURSORS',
+    ]
 
     DEFAULT_CACHE_ENV = 'CACHE_URL'
     CACHE_SCHEMES = {
@@ -90,8 +118,15 @@ class Env(object):
         'pymemcache': 'django.core.cache.backends.memcached.PyLibMCCache',
         'rediscache': REDIS_DRIVER,
         'redis': REDIS_DRIVER,
+        'rediss': REDIS_DRIVER,
     }
-    _CACHE_BASE_OPTIONS = ['TIMEOUT', 'KEY_PREFIX', 'VERSION', 'KEY_FUNCTION', 'BINARY']
+    _CACHE_BASE_OPTIONS = [
+        'TIMEOUT',
+        'KEY_PREFIX',
+        'VERSION',
+        'KEY_FUNCTION',
+        'BINARY',
+    ]
 
     DEFAULT_EMAIL_ENV = 'EMAIL_URL'
     EMAIL_SCHEMES = {
@@ -108,8 +143,14 @@ class Env(object):
 
     DEFAULT_SEARCH_ENV = 'SEARCH_URL'
     SEARCH_SCHEMES = {
-        "elasticsearch": "haystack.backends.elasticsearch_backend.ElasticsearchSearchEngine",
-        "elasticsearch2": "haystack.backends.elasticsearch2_backend.Elasticsearch2SearchEngine",
+        "elasticsearch": "haystack.backends.elasticsearch_backend."
+                         "ElasticsearchSearchEngine",
+        "elasticsearch2": "haystack.backends.elasticsearch2_backend."
+                          "Elasticsearch2SearchEngine",
+        "elasticsearch5": "haystack.backends.elasticsearch5_backend."
+                          "Elasticsearch5SearchEngine",
+        "elasticsearch7": "haystack.backends.elasticsearch7_backend."
+                          "Elasticsearch7SearchEngine",
         "solr": "haystack.backends.solr_backend.SolrEngine",
         "whoosh": "haystack.backends.whoosh_backend.WhooshEngine",
         "xapian": "haystack.backends.xapian_backend.XapianEngine",
@@ -117,10 +158,16 @@ class Env(object):
     }
 
     def __init__(self, **scheme):
+        self.smart_cast = True
         self.scheme = scheme
 
     def __call__(self, var, cast=None, default=NOTSET, parse_default=False):
-        return self.get_value(var, cast=cast, default=default, parse_default=parse_default)
+        return self.get_value(
+            var,
+            cast=cast,
+            default=default,
+            parse_default=parse_default
+        )
 
     def __contains__(self, var):
         return var in self.ENVIRON
@@ -131,7 +178,7 @@ class Env(object):
         """
         :rtype: str
         """
-        value = self.get_value(var, default=default)
+        value = self.get_value(var, cast=str, default=default)
         if multiline:
             return value.replace('\\n', '\n')
         return value
@@ -146,7 +193,10 @@ class Env(object):
         """
         :rtype: bytes
         """
-        return self.get_value(var, cast=str).encode(encoding)
+        value = self.get_value(var, cast=str, default=default)
+        if hasattr(value, 'encode'):
+            return value.encode(encoding)
+        return value
 
     def bool(self, var, default=NOTSET):
         """
@@ -176,13 +226,21 @@ class Env(object):
         """
         :rtype: list
         """
-        return self.get_value(var, cast=list if not cast else [cast], default=default)
+        return self.get_value(
+            var,
+            cast=list if not cast else [cast],
+            default=default
+        )
 
     def tuple(self, var, cast=None, default=NOTSET):
         """
         :rtype: tuple
         """
-        return self.get_value(var, cast=tuple if not cast else (cast,), default=default)
+        return self.get_value(
+            var,
+            cast=tuple if not cast else (cast,),
+            default=default
+        )
 
     def dict(self, var, cast=dict, default=NOTSET):
         """
@@ -194,30 +252,53 @@ class Env(object):
         """
         :rtype: urlparse.ParseResult
         """
-        return self.get_value(var, cast=urlparse, default=default, parse_default=True)
+        return self.get_value(
+            var,
+            cast=urlparse,
+            default=default,
+            parse_default=True
+        )
 
     def db_url(self, var=DEFAULT_DATABASE_ENV, default=NOTSET, engine=None):
         """Returns a config dictionary, defaulting to DATABASE_URL.
 
+        The db method is an alias for db_url.
+
         :rtype: dict
         """
-        return self.db_url_config(self.get_value(var, default=default), engine=engine)
+        return self.db_url_config(
+            self.get_value(var, default=default),
+            engine=engine
+        )
+
     db = db_url
 
     def cache_url(self, var=DEFAULT_CACHE_ENV, default=NOTSET, backend=None):
         """Returns a config dictionary, defaulting to CACHE_URL.
 
+        The cache method is an alias for cache_url.
+
         :rtype: dict
         """
-        return self.cache_url_config(self.url(var, default=default), backend=backend)
+        return self.cache_url_config(
+            self.url(var, default=default),
+            backend=backend
+        )
+
     cache = cache_url
 
     def email_url(self, var=DEFAULT_EMAIL_ENV, default=NOTSET, backend=None):
         """Returns a config dictionary, defaulting to EMAIL_URL.
 
+        The email method is an alias for email_url.
+
         :rtype: dict
         """
-        return self.email_url_config(self.url(var, default=default), backend=backend)
+        return self.email_url_config(
+            self.url(var, default=default),
+            backend=backend
+        )
+
     email = email_url
 
     def search_url(self, var=DEFAULT_SEARCH_ENV, default=NOTSET, engine=None):
@@ -225,7 +306,10 @@ class Env(object):
 
         :rtype: dict
         """
-        return self.search_url_config(self.url(var, default=default), engine=engine)
+        return self.search_url_config(
+            self.url(var, default=default),
+            engine=engine
+        )
 
     def path(self, var, default=NOTSET, **kwargs):
         """
@@ -244,7 +328,7 @@ class Env(object):
         :returns: Value from environment or default (if set)
         """
 
-        logger.debug("get '{0}' casted as '{1}' with default '{2}'".format(
+        logger.debug("get '{}' casted as '{}' with default '{}'".format(
             var, cast, default
         ))
 
@@ -273,18 +357,22 @@ class Env(object):
             value = self.ENVIRON[var]
         except KeyError:
             if default is self.NOTSET:
-                error_msg = "Set the {0} environment variable".format(var)
+                error_msg = "Set the {} environment variable".format(var)
                 raise ImproperlyConfigured(error_msg)
 
             value = default
 
         # Resolve any proxied values
-        if hasattr(value, 'startswith') and value.startswith('$'):
-            value = value.lstrip('$')
+        prefix = b'$' if isinstance(value, bytes) else '$'
+        if hasattr(value, 'startswith') and value.startswith(prefix):
+            value = value.lstrip(prefix)
             value = self.get_value(value, cast=cast, default=default)
 
-        if cast is None and default is not None and not isinstance(default, NoValue):
-            cast = type(default)
+        # Smart casting
+        if self.smart_cast:
+            if cast is None and default is not None and \
+                    not isinstance(default, NoValue):
+                cast = type(default)
 
         if value != default or (parse_default and value):
             value = self.parse_value(value, cast)
@@ -321,7 +409,10 @@ class Env(object):
             value = dict(map(
                 lambda kv: (
                     key_cast(kv[0]),
-                    cls.parse_value(kv[1], value_cast_by_key.get(kv[0], value_cast))
+                    cls.parse_value(
+                        kv[1],
+                        value_cast_by_key.get(kv[0], value_cast)
+                    )
                 ),
                 [val.split('=') for val in value.split(';') if val]
             ))
@@ -334,13 +425,14 @@ class Env(object):
             value = tuple([x for x in val if x])
         elif cast is float:
             # clean string
-            float_str = re.sub(r'[^\d,\.]', '', value)
-            # split for avoid thousand separator and different locale comma/dot symbol
-            parts = re.split(r'[,\.]', float_str)
+            float_str = re.sub(r'[^\d,.-]', '', value)
+            # split for avoid thousand separator and different
+            # locale comma/dot symbol
+            parts = re.split(r'[,.]', float_str)
             if len(parts) == 1:
                 float_str = parts[0]
             else:
-                float_str = "{0}.{1}".format(''.join(parts[0:-1]), parts[-1])
+                float_str = "{}.{}".format(''.join(parts[0:-1]), parts[-1])
             value = float(float_str)
         else:
             value = cast(value)
@@ -349,18 +441,14 @@ class Env(object):
     @classmethod
     def db_url_config(cls, url, engine=None):
         """Pulled from DJ-Database-URL, parse an arbitrary Database URL.
-        Support currently exists for PostgreSQL, PostGIS, MySQL, Oracle and SQLite.
 
-        SQLite connects to file based databases. The same URL format is used, omitting the hostname,
-        and using the "file" portion as the filename of the database.
-        This has the effect of four slashes being present for an absolute file path:
-
-        >>> from environ import Env
-        >>> Env.db_url_config('sqlite:////full/path/to/your/file.sqlite')
-        {'ENGINE': 'django.db.backends.sqlite3', 'HOST': '', 'NAME': '/full/path/to/your/file.sqlite', 'PASSWORD': '', 'PORT': '', 'USER': ''}
-        >>> Env.db_url_config('postgres://uf07k1i6d8ia0v:wegauwhgeuioweg@ec2-107-21-253-135.compute-1.amazonaws.com:5431/d8r82722r2kuvn')
-        {'ENGINE': 'django.db.backends.postgresql', 'HOST': 'ec2-107-21-253-135.compute-1.amazonaws.com', 'NAME': 'd8r82722r2kuvn', 'PASSWORD': 'wegauwhgeuioweg', 'PORT': 5431, 'USER': 'uf07k1i6d8ia0v'}
+        Support currently exists for PostgreSQL, PostGIS, MySQL, Oracle and
+        SQLite.
 
+        SQLite connects to file based databases. The same URL format is used,
+        omitting the hostname, and using the "file" portion as the filename of
+        the database. This has the effect of four slashes being present for an
+        absolute file path.
         """
         if not isinstance(url, cls.URL_CLASS):
             if url == 'sqlite://:memory:':
@@ -383,13 +471,17 @@ class Env(object):
         if url.scheme == 'sqlite':
             if path == '':
                 # if we are using sqlite and we have no path, then assume we
-                # want an in-memory database (this is the behaviour of  sqlalchemy)
+                # want an in-memory database (this is the behaviour of
+                # sqlalchemy)
                 path = ':memory:'
             if url.netloc:
-                warnings.warn(
-                    'SQLite URL contains host component %r, it will be ignored' % url.netloc, stacklevel=3)
+                warnings.warn('SQLite URL contains host component %r, '
+                              'it will be ignored' % url.netloc, stacklevel=3)
         if url.scheme == 'ldap':
-            path = '{scheme}://{hostname}'.format(scheme=url.scheme, hostname=url.hostname)
+            path = '{scheme}://{hostname}'.format(
+                scheme=url.scheme,
+                hostname=url.hostname,
+            )
             if url.port:
                 path += ':{port}'.format(port=url.port)
 
@@ -402,7 +494,7 @@ class Env(object):
             'PORT': _cast_int(url.port) or '',
         })
 
-        if url.scheme == 'postgres' and path.startswith('/'):
+        if url.scheme in cls.POSTGRES_FAMILY and path.startswith('/'):
             config['HOST'], config['NAME'] = path.rsplit('/', 1)
 
         if url.scheme == 'oracle' and path == '':
@@ -412,7 +504,7 @@ class Env(object):
         if url.scheme == 'oracle':
             # Django oracle/base.py strips port and fails on non-string value
             if not config['PORT']:
-                del(config['PORT'])
+                del (config['PORT'])
             else:
                 config['PORT'] = str(config['PORT'])
 
@@ -434,7 +526,7 @@ class Env(object):
             config['ENGINE'] = Env.DB_SCHEMES[config['ENGINE']]
 
         if not config.get('ENGINE', False):
-            warnings.warn("Engine not recognized from url: {0}".format(config))
+            warnings.warn("Engine not recognized from url: {}".format(config))
             return {}
 
         return config
@@ -447,7 +539,16 @@ class Env(object):
         :param backend:
         :return:
         """
-        url = urlparse(url) if not isinstance(url, cls.URL_CLASS) else url
+        if not isinstance(url, cls.URL_CLASS):
+            if not url:
+                return {}
+            else:
+                url = urlparse(url)
+
+        if url.scheme not in cls.CACHE_SCHEMES:
+            raise ImproperlyConfigured(
+                'Invalid cache schema {}'.format(url.scheme)
+            )
 
         location = url.netloc.split(',')
         if len(location) == 1:
@@ -473,8 +574,12 @@ class Env(object):
                 scheme = url.scheme.replace('cache', '')
             else:
                 scheme = 'unix'
-            locations = [scheme + '://' + loc + url.path for loc in url.netloc.split(',')]
-            config['LOCATION'] = locations[0] if len(locations) == 1 else locations
+            locations = [scheme + '://' + loc + url.path
+                         for loc in url.netloc.split(',')]
+            if len(locations) == 1:
+                config['LOCATION'] = locations[0]
+            else:
+                config['LOCATION'] = locations
 
         if url.query:
             config_options = {}
@@ -547,23 +652,32 @@ class Env(object):
         path = unquote_plus(path.split('?', 2)[0])
 
         if url.scheme not in cls.SEARCH_SCHEMES:
-            raise ImproperlyConfigured('Invalid search schema %s' % url.scheme)
+            raise ImproperlyConfigured(
+                'Invalid search schema %s' % url.scheme
+            )
         config["ENGINE"] = cls.SEARCH_SCHEMES[url.scheme]
 
         # check commons params
-        params = {}
+        params = {}  # type: dict
         if url.query:
             params = parse_qs(url.query)
             if 'EXCLUDED_INDEXES' in params.keys():
-                config['EXCLUDED_INDEXES'] = params['EXCLUDED_INDEXES'][0].split(',')
+                config['EXCLUDED_INDEXES'] \
+                    = params['EXCLUDED_INDEXES'][0].split(',')
             if 'INCLUDE_SPELLING' in params.keys():
-                config['INCLUDE_SPELLING'] = cls.parse_value(params['INCLUDE_SPELLING'][0], bool)
+                config['INCLUDE_SPELLING'] = cls.parse_value(
+                    params['INCLUDE_SPELLING'][0],
+                    bool
+                )
             if 'BATCH_SIZE' in params.keys():
-                config['BATCH_SIZE'] = cls.parse_value(params['BATCH_SIZE'][0], int)
+                config['BATCH_SIZE'] = cls.parse_value(
+                    params['BATCH_SIZE'][0],
+                    int
+                )
 
         if url.scheme == 'simple':
             return config
-        elif url.scheme in ['solr', 'elasticsearch', 'elasticsearch2']:
+        elif url.scheme in ['solr'] + cls.ELASTICSEARCH_FAMILY:
             if 'KWARGS' in params.keys():
                 config['KWARGS'] = params['KWARGS'][0]
 
@@ -572,13 +686,14 @@ class Env(object):
             path = path[:-1]
 
         if url.scheme == 'solr':
-            config['URL'] = urlunparse(('http',) + url[1:2] + (path,) + ('', '', ''))
+            config['URL'] = urlunparse(
+                ('http',) + url[1:2] + (path,) + ('', '', '')
+            )
             if 'TIMEOUT' in params.keys():
                 config['TIMEOUT'] = cls.parse_value(params['TIMEOUT'][0], int)
             return config
 
-        if url.scheme in ['elasticsearch', 'elasticsearch2']:
-
+        if url.scheme in cls.ELASTICSEARCH_FAMILY:
             split = path.rsplit("/", 1)
 
             if len(split) > 1:
@@ -588,7 +703,9 @@ class Env(object):
                 path = ""
                 index = split[0]
 
-            config['URL'] = urlunparse(('http',) + url[1:2] + (path,) + ('', '', ''))
+            config['URL'] = urlunparse(
+                ('http',) + url[1:2] + (path,) + ('', '', '')
+            )
             if 'TIMEOUT' in params.keys():
                 config['TIMEOUT'] = cls.parse_value(params['TIMEOUT'][0], int)
             config['INDEX_NAME'] = index
@@ -600,7 +717,10 @@ class Env(object):
             if 'STORAGE' in params.keys():
                 config['STORAGE'] = params['STORAGE'][0]
             if 'POST_LIMIT' in params.keys():
-                config['POST_LIMIT'] = cls.parse_value(params['POST_LIMIT'][0], int)
+                config['POST_LIMIT'] = cls.parse_value(
+                    params['POST_LIMIT'][0],
+                    int
+                )
         elif url.scheme == 'xapian':
             if 'FLAGS' in params.keys():
                 config['FLAGS'] = params['FLAGS'][0]
@@ -614,32 +734,40 @@ class Env(object):
     def read_env(cls, env_file=None, **overrides):
         """Read a .env file into os.environ.
 
-        If not given a path to a dotenv path, does filthy magic stack backtracking
-        to find manage.py and then find the dotenv.
+        If not given a path to a dotenv path, does filthy magic stack
+        backtracking to find the dotenv in the same directory as the file that
+        called read_env.
 
-        http://www.wellfireinteractive.com/blog/easier-12-factor-django/
-
-        https://gist.github.com/bennylope/2999704
+        Refs:
+        - https://wellfire.co/learn/easier-12-factor-django
+        - https://gist.github.com/bennylope/2999704
         """
         if env_file is None:
             frame = sys._getframe()
-            env_file = os.path.join(os.path.dirname(frame.f_back.f_code.co_filename), '.env')
+            env_file = os.path.join(
+                os.path.dirname(frame.f_back.f_code.co_filename),
+                '.env'
+            )
             if not os.path.exists(env_file):
-                warnings.warn(
+                logger.info(
                     "%s doesn't exist - if you're not configuring your "
                     "environment separately, create one." % env_file)
                 return
 
         try:
-            with open(env_file) if isinstance(env_file, basestring) else env_file as f:
-                content = f.read()
-        except IOError:
-            warnings.warn(
-                "Error reading %s - if you're not configuring your "
+            if isinstance(env_file, Openable):
+                with open(env_file) as f:
+                    content = f.read()
+            else:
+                with env_file as f:
+                    content = f.read()
+        except OSError:
+            logger.info(
+                "%s not found - if you're not configuring your "
                 "environment separately, check this." % env_file)
             return
 
-        logger.debug('Read environment variables from: {0}'.format(env_file))
+        logger.debug('Read environment variables from: {}'.format(env_file))
 
         for line in content.splitlines():
             m1 = re.match(r'\A(?:export )?([A-Za-z_0-9]+)=(.*)\Z', line)
@@ -658,31 +786,8 @@ class Env(object):
             cls.ENVIRON.setdefault(key, value)
 
 
-class Path(object):
-
-    """Inspired to Django Two-scoops, handling File Paths in Settings.
-
-        >>> from environ import Path
-        >>> root = Path('/home')
-        >>> root, root(), root('dev')
-        (<Path:/home>, '/home', '/home/dev')
-        >>> root == Path('/home')
-        True
-        >>> root in Path('/'), root not in Path('/other/path')
-        (True, True)
-        >>> root('dev', 'not_existing_dir', required=True)
-        Traceback (most recent call last):
-        environ.environ.ImproperlyConfigured: Create required path: /home/not_existing_dir
-        >>> public = root.path('public')
-        >>> public, public.root, public('styles')
-        (<Path:/home/public>, '/home/public', '/home/public/styles')
-        >>> assets, scripts = public.path('assets'), public.path('assets', 'scripts')
-        >>> assets.root, scripts.root
-        ('/home/public/assets', '/home/public/assets/scripts')
-        >>> assets + 'styles', str(assets + 'styles'), ~assets
-        (<Path:/home/public/assets/styles>, '/home/public/assets/styles', <Path:/home/public>)
-
-    """
+class Path:
+    """Inspired to Django Two-scoops, handling File Paths in Settings."""
 
     def path(self, *paths, **kwargs):
         """Create new Path based on self.root and provided paths.
@@ -711,7 +816,7 @@ class Path(object):
 
     def __init__(self, start='', *paths, **kwargs):
 
-        super(Path, self).__init__()
+        super().__init__()
 
         if kwargs.get('is_file', False):
             start = os.path.dirname(start)
@@ -733,12 +838,14 @@ class Path(object):
         return not self.__eq__(other)
 
     def __add__(self, other):
-        return Path(self.__root__, other if not isinstance(other, Path) else other.__root__)
+        if not isinstance(other, Path):
+            return Path(self.__root__, other)
+        return Path(self.__root__, other.__root__)
 
     def __sub__(self, other):
         if isinstance(other, int):
             return self.path('../' * other)
-        elif isinstance(other, basestring):
+        elif isinstance(other, str):
             if self.__root__.endswith(other):
                 return Path(self.__root__.rstrip(other))
         raise TypeError(
@@ -758,7 +865,7 @@ class Path(object):
         return item.__root__.startswith(base_path)
 
     def __repr__(self):
-        return "<Path:{0}>".format(self.__root__)
+        return "<Path:{}>".format(self.__root__)
 
     def __str__(self):
         return self.__root__
@@ -768,7 +875,7 @@ class Path(object):
 
     def __getitem__(self, *args, **kwargs):
         return self.__str__().__getitem__(*args, **kwargs)
-    
+
     def __fspath__(self):
         return self.__str__()
 
@@ -783,7 +890,7 @@ class Path(object):
         absolute_path = os.path.abspath(os.path.join(base, *paths))
         if kwargs.get('required', False) and not os.path.exists(absolute_path):
             raise ImproperlyConfigured(
-                "Create required path: {0}".format(absolute_path))
+                "Create required path: {}".format(absolute_path))
         return absolute_path
 
 
